IncompatibleKeyError

Enum IncompatibleKeyError 

#[non_exhaustive]
pub enum IncompatibleKeyError { AlgorithmMismatch { requested: Algorithm, declared: Algorithm, }, IncompatibleAlgorithm { algorithm: Algorithm, key_type: KeyType, }, InsufficientKeyStrength { minimum_bits: usize, actual_bits: usize, context: &'static str, }, KeySizeMismatch { required_bits: usize, actual_bits: usize, context: &'static str, }, OperationNotPermitted { operations: Vec<KeyOperation>, reason: String, }, }
The JWK is well-formed but incompatible with the requested use.

These errors indicate the key is structurally valid but cannot be used in the requested context. A key producing an IncompatibleKeyError may be perfectly valid for a different algorithm or operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AlgorithmMismatch

Requested algorithm conflicts with the key’s declared alg value.

Fields

requested: Algorithm

The algorithm that was requested by the caller.

declared: Algorithm

The algorithm declared on the key.



IncompatibleAlgorithm

Algorithm is not compatible with the key type or curve.

Fields

algorithm: Algorithm

The algorithm that was requested.

key_type: KeyType

The key type that is incompatible.



InsufficientKeyStrength

Key is too weak for the requested algorithm.

Fields

minimum_bits: usize

Minimum required size in bits.

actual_bits: usize

Actual key size in bits.

context: &'static str

What was being validated.



KeySizeMismatch

Key size does not match the exact size required by the algorithm.

Fields

required_bits: usize

Required size in bits.

actual_bits: usize

Actual key size in bits.

context: &'static str

What was being validated.



OperationNotPermitted

Requested operation(s) are not permitted by key metadata or key material capability (for example, a public-only key used for signing).

Fields

operations: Vec<KeyOperation>

The disallowed operations.

reason: String

Why the operations are not permitted.