#[non_exhaustive]pub enum InvalidKeyError {
InvalidKeySize {
expected: usize,
actual: usize,
context: &'static str,
},
MissingParameter(&'static str),
InconsistentParameters(String),
InvalidParameter {
name: &'static str,
reason: String,
},
InvalidOtherPrime {
index: usize,
source: Box<InvalidKeyError>,
},
}Expand description
The JWK is malformed.
These errors indicate the key material or metadata is invalid regardless
of how the key is used. A key producing an InvalidKeyError should be
rejected entirely.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidKeySize
Invalid key size for the key type or curve.
Fields
MissingParameter(&'static str)
Missing required parameter for key type.
InconsistentParameters(String)
Inconsistent key parameters (e.g., public and private parts don’t match).
InvalidParameter
Invalid parameter value.
InvalidOtherPrime
Invalid oth entry in multi-prime RSA parameters.
Fields

source: Box<InvalidKeyError>Validation error for this entry.