#[non_exhaustive]pub enum KeyOperation {
Sign,
Verify,
Encrypt,
Decrypt,
WrapKey,
UnwrapKey,
DeriveKey,
DeriveBits,
Unknown(String),
}Expand description
Key operation (RFC 7517 Section 4.3).
Per RFC 7517, unknown key operation values should be accepted to support collision-resistant names and future extensions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Sign
Compute digital signature or MAC.
Verify
Verify digital signature or MAC.
Encrypt
Encrypt content.
Decrypt
Decrypt content.
WrapKey
Encrypt key.
UnwrapKey
Decrypt key.
DeriveKey
Derive key.
DeriveBits
Derive bits not to be used as a key.
Unknown(String)
Unknown or private-use key operation.
Per RFC 7517, key operation values should either be registered in IANA or be a collision-resistant name. Unknown values are preserved.
Implementations
Sourceimpl KeyOperation
impl KeyOperation