SelectionError

Enum SelectionError 

#[non_exhaustive]
pub enum SelectionError { EmptyVerifyAllowlist, UnknownAlgorithm, UnknownOperation, OperationAlgorithmMismatch { operation: KeyOperation, algorithm: Algorithm, }, AlgorithmNotAllowed, AlgorithmMismatch { requested: Algorithm, declared: Algorithm, }, IntentMismatch, InvalidKey(InvalidKeyError), IncompatibleKeyType, KeySuitabilityFailed(IncompatibleKeyError), AmbiguousSelection { count: usize, }, NoMatchingKey, }
Errors returned by strict key selection.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyVerifyAllowlist

Verification selection was requested without a configured allowlist.



UnknownAlgorithm

The requested algorithm is unknown/private and strict selection rejects it.



UnknownOperation

The requested operation is unknown/private and strict selection rejects it.



OperationAlgorithmMismatch

The requested operation is not compatible with the requested algorithm.

Fields

operation: KeyOperation

Operation requested by the caller.

algorithm: Algorithm

Algorithm requested by the caller.



AlgorithmNotAllowed

The requested verification algorithm is not permitted by the allowlist.



AlgorithmMismatch

The requested algorithm conflicts with a key’s declared alg value.

Fields

requested: Algorithm

Algorithm requested by the caller.

declared: Algorithm

Algorithm declared on the matching key.



IntentMismatch

Key metadata (use / key_ops) does not permit the requested operation.



InvalidKey(InvalidKeyError)

The matched key is structurally invalid.



IncompatibleKeyType

Key material type/curve is incompatible with the requested algorithm.



KeySuitabilityFailed(IncompatibleKeyError)

Key failed cryptographic suitability checks (strength/parameter/capability constraints).



AmbiguousSelection

More than one key satisfies strict selection criteria.

Fields

count: usize

Number of matched keys.



NoMatchingKey

No key satisfies strict selection criteria.