KeyUsage

Enum KeyUsage 

#[non_exhaustive]
pub enum KeyUsage { Sign, Verify, Encrypt, Decrypt, WrapKey, UnwrapKey, }
Available on crate feature web-crypto and WebAssembly only.
Key usage category for determining the appropriate algorithm.

This is used by the low-level import_key_for_usage and import_key_for_usage_with_alg functions to select the correct WebCrypto algorithm parameters at import time.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Sign

The key will be used for signing.



Verify

The key will be used for signature verification.



Encrypt

The key will be used for encryption.



Decrypt

The key will be used for decryption.



WrapKey

The key will be used for wrapping other keys.



UnwrapKey

The key will be used for unwrapping other keys.