KeyUse

Enum KeyUse 

pub enum KeyUse {
    Signature,
    Encryption,
    Unknown(String),
}
Key use (RFC 7517 Section 4.2).

Per RFC 7517, the “use” parameter is intended to identify the intended use of the public key. While “sig” and “enc” are the defined values, the specification allows for other values via registration or collision-resistant names for private use.

Variants



Signature

Key is used for signatures.



Encryption

Key is used for encryption.



Unknown(String)

Unknown or private-use key use.

Per RFC 7517, key use values should either be registered in IANA or be a collision-resistant name. Unknown values are preserved.

Implementations

Source

impl KeyUse

pub fn as_str(&self) -> &str

Returns the key use as a string.

pub fn is_unknown(&self) -> bool

Returns true if this is an unknown/unrecognized key use.